/**************************************************************************
/* ShadowJAAS - a JAAS authentication provider for the
/* shadow-password system of Linux.
/*
/* Copyright (c) 2002 by Bernhard Bablok (mail@bablokb.de)
/*
/* This program is free software; you can redistribute it and/or modify
/* it under the terms of the GNU Library General Public License as published
/* by  the Free Software Foundation; either version 2 of the License or
/* (at your option) any later version.
/*
/* This program is distributed in the hope that it will be useful, but
/* WITHOUT ANY WARRANTY; without even the implied warranty of
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/* GNU Library General Public License for more details.
/*
/* You should have received a copy of the GNU Library General Public License
/* along with this program; see the file COPYING.LIB.  If not, write to
/* the Free Software Foundation Inc., 59 Temple Place - Suite 330,
/* Boston, MA  02111-1307 USA
/**************************************************************************/

package test;

import java.io.*;
import java.util.*;
import java.security.*;
import javax.security.auth.*;
import javax.security.auth.callback.*;
import javax.security.auth.login.*;
import javax.security.auth.spi.*;

import com.sun.security.auth.callback.*;

/**
   This is a test class. It logs into the system, prints out all principals
   and tries to execute some restricted code. A sample jaas-configuration
   file called jaas.config is supplied in the etc-directory of the
   distribution.

   @version $Revision: 1.2 $
   @author  $Author: Bablokb $
*/

public class ShadowJaasTest {

  private LoginContext iContext = null;
  private Subject iSubject = null;

  ////////////////////////////////////////////////////////////////////////////

  /**
     Main entry point.
  */

  public static void main(String[] args) {
    ShadowJaasTest t = new ShadowJaasTest();
    t.login();
    t.printPrincipals();
    t.runRestrictedCode();
    System.exit(0);
  }
  
  ////////////////////////////////////////////////////////////////////////////

  /**
     Login using the defined configuration.
  */

  private void login() {
    try {
      iContext = new LoginContext("Shadow", new TextCallbackHandler());
      iContext.login();
      System.out.println("login successful");
      iSubject = iContext.getSubject();
    } catch (AccountExpiredException e1) {
      System.out.println("account expired");
      System.exit(3);
    } catch (CredentialExpiredException e2) {
      System.out.println("credentials expired");
      System.exit(3);
    } catch (FailedLoginException e3) {
      System.out.println("authentication failed");
      System.exit(3);
    } catch (Exception e4) {
      System.out.println("unexpected exception:");
      e4.printStackTrace();
      System.exit(3);
    }
  }

  ////////////////////////////////////////////////////////////////////////////

  /**
     Print all principals of subject.
  */

  private void printPrincipals() {
    Iterator principalIterator = iSubject.getPrincipals().iterator();
    System.out.println("\n\nList of principals:");
    while (principalIterator.hasNext()) {
      Principal p = (Principal) principalIterator.next();
      System.out.println("\t" + p.toString());
    }
    System.out.println("\n\n");    
  }

  ////////////////////////////////////////////////////////////////////////////

  /**
     Run some (possibly) restricted code.
  */

  private void runRestrictedCode() {
    try {
      Subject.doAsPrivileged(iSubject,new Restricted(),null);
    } catch (AccessControlException e5) {
      System.out.println("access to restricted code denied");
    }
  }
}

